## Description

<!-- Choose one of the following prefixes for the title of your PR:

     [ENH] for enhancements
     [FIX] for bug fixes
     [TST] for new or updated tests
     [DOC] for new or updated documentation
     [STY] for stylistic changes
     [REF] for refactoring existing code

     If your PR is not yet ready to be merged, also add [WIP] to label it as a "work in progress".

     If this is a bug-fix or enhancement, state the issue # it closes.
     If this is a new feature, reference what paper it implements.
-->

## Checklist

<!-- It's fine to submit PRs which are a work in progress!
     But before they are merged, all PRs should provide: -->
- [ ] [Docstrings for all functions](https://github.com/numpy/numpy/blob/master/doc/example.py)
- [ ] Gallery example in `./examples` (new features only)
- [ ] Unit tests
- [ ] Clean style in [the spirit of PEP8](https://www.python.org/dev/peps/pep-0008/)

<!-- For detailed information on these and other aspects, see the contribution guidelines:
     https://pulse2percept.readthedocs.io/en/latest/developers/contributing.html -->
